"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var DEFAULT_CONFIG = {
    timeout: 5000,
    withCredentials: true,
    validateStatus: function (status) { return status >= 200 && status < 599; }
};
var Http = /** @class */ (function () {
    function Http(baseUrl, config) {
        if (config === void 0) { config = {}; }
        this.isSetInstancesToken = false;
        this.source = axios_1.default.CancelToken.source();
        this.instanceTokenConfig = {
            authorizationTypeKey: 'Authorization',
            authorizationTokenKey: 'authorization_type',
            authorizationTypeValue: 0,
            authorizationTokenValue: ''
        };
        var axiosIns = axios_1.default.create(__assign({ baseURL: baseUrl }, DEFAULT_CONFIG, config));
        Http.INSTANCES[baseUrl] = axiosIns;
        this.axiosIns = axiosIns;
    }
    // 设置单个实例的token与tokenType
    Http.prototype.setInstanceTokenConfig = function (instanceTokenConfig) {
        this.isSetInstancesToken = true;
        this.instanceTokenConfig = __assign({}, this.instanceTokenConfig, instanceTokenConfig);
    };
    Http.prototype.request = function (opt) {
        var _a, _b;
        var _opt = Object.assign({}, opt);
        if (this.isSetInstancesToken) {
            var _c = this.instanceTokenConfig, authorizationTypeValue = _c.authorizationTypeValue, authorizationTokenValue = _c.authorizationTokenValue, authorizationTypeKey = _c.authorizationTypeKey, authorizationTokenKey = _c.authorizationTokenKey;
            if (authorizationTypeKey && authorizationTypeValue && authorizationTokenKey && authorizationTokenValue) {
                _opt.headers = __assign((_a = {}, _a[authorizationTypeKey] = authorizationTypeValue, _a[authorizationTokenKey] = authorizationTokenValue, _a), _opt.headers);
            }
        }
        else {
            var _d = Http.globalTokenConfig, authorizationTypeValue = _d.authorizationTypeValue, authorizationTokenValue = _d.authorizationTokenValue, authorizationTypeKey = _d.authorizationTypeKey, authorizationTokenKey = _d.authorizationTokenKey;
            if (authorizationTypeKey && authorizationTypeValue && authorizationTokenKey && authorizationTokenValue) {
                _opt.headers = __assign((_b = {}, _b[authorizationTypeKey] = authorizationTypeValue, _b[authorizationTokenKey] = authorizationTokenValue, _b), _opt.headers);
            }
        }
        _opt.cancelToken = this.source.token;
        return this.axiosIns.request(_opt);
    };
    Http.prototype.abort = function () {
        this.source.cancel('API abort.');
    };
    Http.prototype.get = function (url, configs) {
        return this.request(__assign({ method: 'get', url: url }, configs));
    };
    Http.prototype.post = function (url, data, configs) {
        return this.request(__assign({ method: 'post', url: url,
            data: data }, configs));
    };
    Http.prototype.put = function (url, data, configs) {
        return this.request(__assign({ method: 'put', url: url,
            data: data }, configs));
    };
    Http.prototype.patch = function (url, data, configs) {
        return this.request(__assign({ method: 'patch', url: url,
            data: data }, configs));
    };
    Http.prototype.delete = function (url, configs) {
        return this.request(__assign({ method: 'delete', url: url }, configs));
    };
    // 全局设置token与tokenType
    Http.setGlobalTokenConfig = function (globalTokenConfig) {
        Http.globalTokenConfig = __assign({}, Http.globalTokenConfig, globalTokenConfig);
    };
    // 获取相对应的实例
    Http.getInstances = function (key) {
        return Http.INSTANCES[key];
    };
    // 设置请求拦截器
    Http.setReqInterceptor = function (resolve, reject, url) {
        if (url) {
            var interceptorsId = Http.INSTANCES_REQUEST_INTERCEPTORS[url];
            var instance = Http.INSTANCES[url];
            if (interceptorsId !== undefined) {
                instance.interceptors.request.eject(interceptorsId);
            }
            if (instance) {
                var CreateInterceptorsId = instance.interceptors.request.use(resolve, reject);
                Http.INSTANCES_REQUEST_INTERCEPTORS[url] = CreateInterceptorsId;
            }
        }
        else {
            for (var key in Http.INSTANCES) {
                if (Http.INSTANCES_REQUEST_INTERCEPTORS[key] === undefined) {
                    var instance = Http.INSTANCES[key];
                    var interceptorsId = instance.interceptors.request.use(resolve, reject);
                    Http.INSTANCES_REQUEST_INTERCEPTORS[key] = interceptorsId;
                }
            }
        }
    };
    // 设置响应拦截器
    Http.setResInterceptor = function (resolve, reject, url) {
        if (url) {
            var interceptorsId = Http.INSTANCES_RESPONSE_INTERCEPTORS[url];
            var instance = Http.INSTANCES[url];
            if (interceptorsId !== undefined) {
                instance.interceptors.response.eject(interceptorsId);
            }
            if (instance) {
                var CreateInterceptorsId = instance.interceptors.response.use(resolve, reject);
                Http.INSTANCES_RESPONSE_INTERCEPTORS[url] = CreateInterceptorsId;
            }
        }
        else {
            for (var key in Http.INSTANCES) {
                if (Http.INSTANCES_RESPONSE_INTERCEPTORS[key] === undefined) {
                    var instance = Http.INSTANCES[key];
                    var CreateInterceptorsId = instance.interceptors.response.use(resolve, reject);
                    Http.INSTANCES_RESPONSE_INTERCEPTORS[key] = CreateInterceptorsId;
                }
            }
        }
    };
    Http.globalTokenConfig = {
        authorizationTypeKey: 'Authorization',
        authorizationTokenKey: 'authorization_type',
        authorizationTypeValue: 0,
        authorizationTokenValue: ''
    };
    Http.INSTANCES = {};
    Http.INSTANCES_REQUEST_INTERCEPTORS = {};
    Http.INSTANCES_RESPONSE_INTERCEPTORS = {};
    return Http;
}());
exports.Http = Http;
//# sourceMappingURL=mlz_axios.js.map